'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const vscode_jsonrpc_1 = require("vscode-jsonrpc");
const vscode_1 = require("vscode");
const vscode_languageclient_1 = require("vscode-languageclient");
const path = require("path");
const protocol_colorProvider_proposed_1 = require("vscode-languageserver-protocol/lib/protocol.colorProvider.proposed");
var OpenDocNotification;
(function (OpenDocNotification) {
    OpenDocNotification.type = new vscode_languageclient_1.NotificationType('stylable/openDocumentNotification');
})(OpenDocNotification || (OpenDocNotification = {}));
function activate(context) {
    // path.join(__dirname, '..', 'server', 'server.js'); //
    let serverModule = path.join(__dirname, '..', 'server', 'server.js'); //context.asAbsolutePath(path.join('dist', 'src', 'server', 'server.js'));
    let debugOptions = { execArgv: ['--inspect'] };
    let serverOptions = {
        run: { module: serverModule, transport: vscode_languageclient_1.TransportKind.ipc },
        debug: { module: serverModule, transport: vscode_languageclient_1.TransportKind.ipc, options: debugOptions, runtime: 'node' }
    };
    let clientOptions = {
        documentSelector: [{ language: 'stylable' }, { language: 'typescript' }, { language: 'javascript' },],
        diagnosticCollectionName: 'stylable',
    };
    let client = new vscode_languageclient_1.LanguageClient('stylable', serverOptions, clientOptions);
    client.trace = vscode_jsonrpc_1.Trace.Verbose;
    context.subscriptions.push(client.start());
    return client
        .onReady()
        .then(_ => {
        context.subscriptions.push(vscode_1.languages.registerColorProvider('stylable', {
            provideDocumentColors(document) {
                let params = {
                    textDocument: client.code2ProtocolConverter.asTextDocumentIdentifier(document)
                };
                return client.sendRequest(protocol_colorProvider_proposed_1.DocumentColorRequest.type, params).then(symbols => {
                    return symbols.map(symbol => {
                        let range = client.protocol2CodeConverter.asRange(symbol.range);
                        let color = new vscode_1.Color(symbol.color.red, symbol.color.green, symbol.color.blue, symbol.color.alpha);
                        return new vscode_1.ColorInformation(range, color);
                    });
                });
            },
            provideColorPresentations(color, context) {
                let params = {
                    textDocument: client.code2ProtocolConverter.asTextDocumentIdentifier(context.document),
                    color,
                    range: client.code2ProtocolConverter.asRange(context.range)
                };
                return client.sendRequest(protocol_colorProvider_proposed_1.ColorPresentationRequest.type, params).then(presentations => {
                    return presentations.map(p => {
                        let presentation = new vscode_1.ColorPresentation(p.label);
                        presentation.textEdit = p.textEdit && client.protocol2CodeConverter.asTextEdit(p.textEdit);
                        presentation.additionalTextEdits = p.additionalTextEdits && client.protocol2CodeConverter.asTextEdits(p.additionalTextEdits);
                        return presentation;
                    });
                });
            }
        }));
    })
        .then(() => vscode_1.workspace.findFiles('**/*.st.css'))
        .then((files) => Promise.all(files.map((file) => vscode_1.workspace.openTextDocument(file.fsPath))))
        .then(() => client.onNotification(OpenDocNotification.type, (uri) => vscode_1.workspace.openTextDocument(vscode_1.Uri.parse(uri)).then((doc) => {
        if (doc.fileName.endsWith('.js')) {
            vscode_1.workspace.findFiles('**/' + path.basename(doc.fileName).slice(0, -3) + '.d.ts').then((uris) => {
                uris.forEach(u => {
                    vscode_1.workspace.openTextDocument(u);
                });
            });
        }
    })))
        .then(() => client);
}
exports.activate = activate;
//# sourceMappingURL=extension.js.map