import * as PostCss from 'postcss';
import { StylableMeta, Stylable } from 'stylable';
import { ProviderPosition, ProviderRange, CompletionProvider } from './completion-providers';
import { Completion } from './completion-types';
import { Position, SignatureHelp, ParameterInformation, ReferenceParams, Location } from 'vscode-languageserver';
import * as ts from 'typescript';
import { ExtendedFSReadSync, ExtendedTsLanguageService } from './types';
export default class Provider {
    styl: Stylable;
    tsLangService: ExtendedTsLanguageService;
    constructor(styl: Stylable, tsLangService: ExtendedTsLanguageService);
    providers: CompletionProvider[];
    provideCompletionItemsFromSrc(src: string, pos: Position, fileName: string, fs: ExtendedFSReadSync): Thenable<Completion[]>;
    private createProviderOptions(src, position, meta, fakeRules, fullLineText, cursorPosInLine, fs);
    private dedupeComps(completions);
    getDefinitionLocation(src: string, position: ProviderPosition, filePath: string, fs: ExtendedFSReadSync): Thenable<ProviderLocation[]>;
    inDef(position: ProviderPosition, def: ProviderLocation): boolean;
    findWord(word: string, src: string, position: Position): ProviderRange;
    escapeRegExp(re: string): string;
    getSignatureHelp(src: string, pos: Position, filePath: string, fs: ExtendedFSReadSync, paramInfo: typeof ParameterInformation): SignatureHelp | null;
    getSignatureForTsModifier(mixin: string, activeParam: number, filePath: string, isDefault: boolean, paramInfo: typeof ParameterInformation): SignatureHelp | null;
    getSignatureForJsModifier(mixin: string, activeParam: number, fileSrc: string, paramInfo: typeof ParameterInformation): SignatureHelp | null;
    getRefs(params: ReferenceParams, fs: ExtendedFSReadSync): Location[];
    findClassRefs(word: string, uri: string, fs: ExtendedFSReadSync): Location[];
}
export declare function createMeta(src: string, path: string): {
    meta: null;
    fakes: PostCss.Rule[];
} | {
    meta: StylableMeta;
    fakes: PostCss.Rule[];
};
export declare function fixAndProcess(src: string, position: ProviderPosition, filePath: string): {
    processed: {
        meta: null;
        fakes: PostCss.Rule[];
    } | {
        meta: StylableMeta;
        fakes: PostCss.Rule[];
    };
    currentLine: string;
    cursorLineIndex: number;
};
export declare class ProviderLocation {
    uri: string;
    range: ProviderRange;
    constructor(uri: string, range: ProviderRange);
}
export declare function extractTsSignature(filePath: string, mixin: string, isDefault: boolean, tsLangService: ExtendedTsLanguageService): ts.Signature | undefined;
export declare function extractJsModifierRetrunType(mixin: string, activeParam: number, fileSrc: string): string;
export declare function isDirective(line: string): boolean;
export declare function isInValue(lineText: string, position: ProviderPosition): boolean;
export declare function getNamedValues(src: string, lineIndex: number): {
    isNamedValueLine: boolean;
    namedValues: string[];
};
export declare function getExistingNames(lineText: string, position: ProviderPosition): {
    names: string[];
    lastName: string;
};
