'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const vscode_languageserver_1 = require("vscode-languageserver");
const provider_factory_1 = require("./provider-factory");
const protocol_colorProvider_proposed_1 = require("vscode-languageserver-protocol/lib/protocol.colorProvider.proposed");
const uri_utils_1 = require("./utils/uri-utils");
const service_1 = require("./service");
const stylable_1 = require("stylable");
const local_sync_fs_1 = require("./local-sync-fs");
const ts = require("typescript");
const temp_language_service_host_1 = require("./utils/temp-language-service-host");
const connection = vscode_languageserver_1.createConnection(new vscode_languageserver_1.IPCMessageReader(process), new vscode_languageserver_1.IPCMessageWriter(process));
const docs = new vscode_languageserver_1.TextDocuments();
docs.listen(connection);
connection.listen();
const fileSystem = new local_sync_fs_1.LocalSyncFs('');
function createDocFs(fileSystem, docs) {
    return {
        __proto__: fileSystem,
        loadTextFile(path) { return Promise.resolve(this.loadTextFileSync(path)); },
        loadTextFileSync(path) {
            const vscodePath = uri_utils_1.toVscodePath(path);
            const fromDocs = docs.get(vscodePath);
            return fromDocs ? fromDocs.getText() : fileSystem.loadTextFileSync(uri_utils_1.fromVscodePath(path));
        },
        get(path) {
            return docs.get(path) || vscode_languageserver_1.TextDocument.create(path, 'stylable', 0, this.loadTextFileSync(uri_utils_1.fromVscodePath(path)));
        },
        getOpenedFiles() {
            return docs.keys();
        }
    };
}
exports.createDocFs = createDocFs;
const docFs = createDocFs(fileSystem, docs);
const styl = new stylable_1.Stylable('/', provider_factory_1.createFs(docFs, true), () => ({ default: {} }));
const OpenDocNotificationType = new vscode_languageserver_1.NotificationType('stylable/openDocumentNotification');
let openedFiles = [];
const tsLanguageServiceHost = temp_language_service_host_1.createLanguageServiceHost({
    cwd: '/',
    getOpenedDocs: () => openedFiles,
    compilerOptions: {
        target: ts.ScriptTarget.ES5, sourceMap: false, declaration: true, outDir: 'dist',
        lib: [],
        module: ts.ModuleKind.CommonJS,
        typeRoots: ["./node_modules/@types"]
    },
    defaultLibDirectory: '',
    baseHost: temp_language_service_host_1.createBaseHost(docFs, path)
});
const tsLanguageService = ts.createLanguageService(tsLanguageServiceHost);
const wrappedTs = {
    setOpenedFiles: (files) => openedFiles = files,
    ts: tsLanguageService
};
const service = new service_1.StylableLanguageService(connection, { styl, tsLanguageService: wrappedTs }, docFs, docs, {
    openDoc: OpenDocNotificationType,
    colorPresentationRequest: protocol_colorProvider_proposed_1.ColorPresentationRequest,
    colorRequest: protocol_colorProvider_proposed_1.DocumentColorRequest
});
//# sourceMappingURL=server.js.map